@@ -4,12 +4,12 @@
 <context>
     <name>NotificationActionsComboWidget</name>
     <message>
-        <location filename="../notificationwidgets.cpp" line="103"/>
+        <location filename="../notificationwidgets.cpp" line="123"/>
         <source>Actions:</source>
         <translation>Accions:</translation>
     </message>
     <message>
-        <location filename="../notificationwidgets.cpp" line="122"/>
+        <location filename="../notificationwidgets.cpp" line="142"/>
         <source>OK</source>
         <translation>D&apos;acord</translation>
     </message>
@@ -17,23 +17,23 @@
 <context>
     <name>Notifyd</name>
     <message>
-        <location filename="../notifyd.cpp" line="227"/>
+        <location filename="../notifyd.cpp" line="268"/>
         <source>Clear All</source>
         <translation>Neteja-ho tot</translation>
     </message>
     <message>
-        <location filename="../notifyd.cpp" line="235"/>
+        <location filename="../notifyd.cpp" line="276"/>
         <source>Options</source>
         <translation>Opcions</translation>
     </message>
     <message numerus="yes">
-        <location filename="../notifyd.cpp" line="242"/>
-        <location filename="../notifyd.cpp" line="300"/>
-        <location filename="../notifyd.cpp" line="320"/>
+        <location filename="../notifyd.cpp" line="283"/>
+        <location filename="../notifyd.cpp" line="340"/>
+        <location filename="../notifyd.cpp" line="360"/>
         <source>%n Unattended Notification(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%n Notificació no atesa</numerusform>
+            <numerusform>%n Notificacions no ateses</numerusform>
         </translation>
     </message>
 </context>
